@@ -232,10 +232,15 @@ def test_empty_name():
 
 
 def test_forbidden_name_usage():
-    with pytest.raises(TypeError):
+    with pytest.raises(AttributeError, match="may not be set on pikepdf.Name"):
         Name.Monty = Name.Python
-    with pytest.raises(TypeError):
+    with pytest.raises(TypeError, match="not subscriptable"):
         Name['/Monty']  # pylint: disable=pointless-statement
+    if sys.implementation.name == 'pypy':
+        pytest.xfail(reason="pypy seems to do setattr differently")
+    with pytest.raises(AttributeError, match="has no attribute"):
+        monty = Name.Monty
+        monty.Attribute = 42
 
 
 class TestHashViolation:
@@ -502,6 +507,24 @@ class TestStreamReadWrite:
         stream_object.write(b'pi')
         assert bytes(stream_object) == b'pi'
 
+    def test_invalid_filter(self, stream_object):
+        with pytest.raises(TypeError, match="filter must be"):
+            stream_object.write(b'foo', filter=[42])
+
+    def test_invalid_decodeparms(self, stream_object):
+        with pytest.raises(TypeError, match="decode_parms must be"):
+            stream_object.write(
+                compress(b'foo'), filter=Name.FlateDecode, decode_parms=[42]
+            )
+
+    def test_filter_decodeparms_mismatch(self, stream_object):
+        with pytest.raises(ValueError, match=r"filter.*and decode_parms"):
+            stream_object.write(
+                compress(b'foo'),
+                filter=[Name.FlateDecode],
+                decode_parms=[Dictionary(), Dictionary()],
+            )
+
 
 def test_copy():
     d = Dictionary(
